@@ -1,11 +1,13 @@
 import fcntl
 import logging
 import os
+from django.conf import settings
+
 def management_lock(view_func):
 
     def wrapper_lock(*args, **kwargs):
         try:
-            lock_file_path = "{0}.lock".format(args[0].__class__.__module__.split('.')[-1])
+            lock_file_path = os.path.join(settings.BASE_DIR, "{0}.lock".format(args[0].__class__.__module__.split('.')[-1]))
             f = open(lock_file_path, 'w')
             fcntl.lockf(f, fcntl.LOCK_EX + fcntl.LOCK_NB)
         except IOError:
